<?php 
/*
 * Plugin Name:       Easy Call To Action
 * Description:       Generate custom call to action shortcodes to paste inside a post, page or widget section.
 * Version:           1.0
 * Requires at least: 5.2
 * Requires PHP:      7.2
 * Author:            CodingWithMica
 * Author URI:        https://codingwithmica.com/
 * License:           GPL v2 or later
 * License URI:       https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain:       mica_ecta
 */
define('MICA_ECTA_PATH', plugin_dir_path(__FILE__));
define('MICA_ECTA_PLUGIN_SLUG', 'easy-call-to-action');

// Includes
require_once MICA_ECTA_PATH . "/db/ecta_db.php";
require_once MICA_ECTA_PATH . "/inc/admin/easy-call-to-action.php";
require_once MICA_ECTA_PATH . "/inc/admin/ecta-settings.php";
require_once MICA_ECTA_PATH . '/inc/ecta.class.php';

// Activation
function mica_ecta_plugin_activation(){
    mica_ecta_create_tables();
}
register_activation_hook(__FILE__, 'mica_ecta_plugin_activation');

// Deactivation
function mica_ecta_plugin_deactivation(){
    flush_rewrite_rules();
    $setting = get_option('mecta_settings');
    if($setting == 'on'){
        mica_ecta_remove_tables();
    }
}
register_deactivation_hook(__FILE__, 'mica_ecta_plugin_deactivation');

// Uninstall
function mica_ecta_plugin_uninstall(){
    delete_option( 'mecta_settings' );
}
register_uninstall_hook(__FILE__, 'mica_ecta_plugin_uninstall');

// Scripts
function mica_ecta_scripts($hook){
    //echo "<script>console.log('$hook')</script>";
    if($hook == "toplevel_page_" . MICA_ECTA_PLUGIN_SLUG || $hook == MICA_ECTA_PLUGIN_SLUG .'_page_'.MICA_ECTA_PLUGIN_SLUG.'-settings'){

        if($hook != MICA_ECTA_PLUGIN_SLUG .'_page_'.MICA_ECTA_PLUGIN_SLUG.'-settings'){
            wp_enqueue_script('popper_js', plugins_url('assets/js/dependencies/popper.js',__FILE__), ['jquery']);
            wp_enqueue_script('bootstrap_js', plugins_url('assets/js/dependencies/bootstrap.js',__FILE__), ['jquery', 'popper_js']);
            wp_enqueue_script('jqueryvalidate_js', plugins_url('assets/js/dependencies/jquery_validate.js',__FILE__), ['jquery']);
            wp_enqueue_script('mica_ecta_js', plugins_url('assets/js/mica_ecta.js',__FILE__), ['jquery', 'popper_js', 'bootstrap_js']);
            wp_localize_script('mica_ecta_js','SolicitudesAjax',[
                'url' => admin_url('admin-ajax.php'),
                'seguridad' => wp_create_nonce('seg')
            ]);
        }
        
        wp_enqueue_style('fonts_google', 'https://fonts.googleapis.com/css2?family=Roboto:ital,wght@0,100;0,200;0,300;0,400;0,500;0,700;0,900;1,400;1,500;1,700;1,900&display=swap');
        wp_enqueue_style('bootstrap_css', plugins_url('assets/css/dependencies/bootstrap.css',__FILE__));
        wp_enqueue_style('mica_ecta_css', plugins_url('assets/css/mica_ecta.css',__FILE__));   
    } else{
        return false;
    }
}
add_action('admin_enqueue_scripts','mica_ecta_scripts', 99);

// Admin dynamic style
add_action('admin_head', 'mica_ecta_style');
function mica_ecta_style() {
  echo '<style>
    #toplevel_page_'. MICA_ECTA_PLUGIN_SLUG .' img {
        max-width: 25px;
        padding: 4px 0 0 !important;
        margin: auto;
    }
  </style>';
} 

// Menu
add_action('admin_menu','mica_ecta_create_menu');
function mica_ecta_create_menu(){
    add_menu_page(
        'Easy Call To Action',
        'Easy Call To Action',
        'manage_options',
        MICA_ECTA_PLUGIN_SLUG,
        'ecta_options',
        plugin_dir_url(__FILE__) . 'assets/img/admin/favicon.svg'
    );
}

// Copytight
function mica_ecta_remove_footer_admin($currentmessage){
    global $pagenow;
    if ( $pagenow == 'admin.php' ){
        return '<div class="mecta_donate">Wanna help me build more plugins? <a target="_blank" href="https://buymeacoffee.com/codingwithmica">Buy me a coffee ☕🤍</a></div>
        <span id="footer-thankyou" style="font-size: 16px">Developed with 💖 by <a href="https://codingwithmica.com/?from=ECTA" target="_blank" style="color: #a663cc; font-weight: bold">Micaela</a></span>';
    } else {
        return $currentmessage;
    }
}
add_filter('admin_footer_text', 'mica_ecta_remove_footer_admin');

// Delete call to action
function mica_ecta_deleteCTA(){
    $nonce = $_POST['nonce'];
    if(!wp_verify_nonce($nonce, 'seg')){
        die('You don\'t have permissions to delete this.');
    }

    $id = sanitize_text_field($_POST['id']);
    global $wpdb;
    $tabla = "{$wpdb->prefix}mica_ecta";
    $wpdb->delete($tabla,array('cta_id' => $id));
    return true;
}
add_action('wp_ajax_peticioneliminar','mica_ecta_deleteCTA');

// Duplicate call to action
function mica_ecta_duplicateCTA(){
    $nonce = $_POST['nonce'];
    if(!wp_verify_nonce($nonce, 'seg')){
        die('You don\'t have permissions to duplicate this.');
    }

    $id = sanitize_text_field($_POST['id']);
    global $wpdb;
    $tabla = "{$wpdb->prefix}mica_ecta";

    $mica_ecta_query_duplicate = "SELECT * FROM $tabla WHERE cta_id = $id";
    $lista_ctas_duplicate = $wpdb->get_results($mica_ecta_query_duplicate,ARRAY_A);
    $lista_ctas_duplicate = $lista_ctas_duplicate[0];
    $lista_ctas_duplicate['cta_id'] = null;
    
    $wpdb->insert($tabla,$lista_ctas_duplicate);
    return true;
}
add_action('wp_ajax_peticionduplicar','mica_ecta_duplicateCTA');

// Print shortcode
function mica_ecta_print_shortcode($atts){
    $_short = new ecta;
    $id= $atts['id'];

    $html = $_short->mica_ecta_armador($id);
    return $html;
}
add_shortcode("ecta","mica_ecta_print_shortcode");

// Settings
function mica_ecta_options_page(){
	add_submenu_page(
		MICA_ECTA_PLUGIN_SLUG,
		'Settings',
		'Settings',
		'manage_options',
		MICA_ECTA_PLUGIN_SLUG .'-settings',
		'mica_ecta_settings'
	);
}
add_action('admin_menu', 'mica_ecta_options_page');